@@ -1,6 +1,7 @@
 import json
 
 from cc_py_commons.sns.sns_service import SnsService
+from cc_py_commons.utils.logger import logger
 
 class BookLoadNotification:
 
@@ -12,7 +13,12 @@ class BookLoadNotification:
                     f'"loadId": "{load_id}", ' \
                     f'"subject" : "{self._app_config.BOOK_LOAD_SNS_SUBJECT}", ' \
                     f'"className":  "{self._app_config.BOOK_LOAD_SNS_CLASS_NAME}"' + '}'
-    print(f"sending messsage {message} to {self._app_config.BOOK_LOAD_SNS_TOPIC_ARN}")
-    sns_service = SnsService()
-    sns_service.send(self._app_config.BOOK_LOAD_SNS_TOPIC_ARN,
-      self._app_config.BOOK_LOAD_SNS_SUBJECT, message)
+    logger.debug(f"sending messsage {message} to {self._app_config.BOOK_LOAD_SNS_TOPIC_ARN}")
+
+    try:
+      sns_service = SnsService()
+      sns_service.send(self._app_config.BOOK_LOAD_SNS_TOPIC_ARN,
+        self._app_config.BOOK_LOAD_SNS_SUBJECT, message)
+    except: 
+      logger.debug(f"failed to send message to {self._app_config.BOOK_LOAD_SNS_TOPIC_ARN}: {message}")
+      
